pub enum TarSplitItem {
Segment(Vec<u8>),
FileContent {
fd: OwnedFd,
size: u64,
name: String,
},
}Expand description
Item returned from tar-split stream iteration.
Variants
Segment(Vec<u8>)
Raw segment bytes (TAR header + padding) to write directly.
FileContent
File content to write.
Fields

fd: OwnedFdFile descriptor for reading the content.
The caller takes ownership of this file descriptor and is responsible for reading the content and closing it when done.